summaryrefslogtreecommitdiffstats
path: root/cmakemodules/FindKdeLibs.cmake
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-11-06 02:23:39 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-11-06 02:23:39 -0600
commit063c9e3c7d9f66bc40a40a57c2ac12e89aefc490 (patch)
tree4f51ceb782b820dbda9dfc536300ed6d1339b075 /cmakemodules/FindKdeLibs.cmake
parentd68f18f521d8f48840a99e664a1550d26e448a5a (diff)
downloadtdesvn-063c9e3c7d9f66bc40a40a57c2ac12e89aefc490.tar.gz
tdesvn-063c9e3c7d9f66bc40a40a57c2ac12e89aefc490.zip
Additional kde to tde renaming
Diffstat (limited to 'cmakemodules/FindKdeLibs.cmake')
-rw-r--r--cmakemodules/FindKdeLibs.cmake14
1 files changed, 7 insertions, 7 deletions
diff --git a/cmakemodules/FindKdeLibs.cmake b/cmakemodules/FindKdeLibs.cmake
index 865f582..2083c3f 100644
--- a/cmakemodules/FindKdeLibs.cmake
+++ b/cmakemodules/FindKdeLibs.cmake
@@ -7,7 +7,7 @@ include(FindQt3)
# KDE3_INCLUDE_DIR - the KDE include directory
# KDE3_INCLUDE_DIRS - the KDE and the Qt include directory, for use with INCLUDE_DIRECTORIES()
# KDE3_LIB_DIR - the directory where the KDE libraries are installed, for use with LINK_DIRECTORIES()
# QT_AND_KDECORE_LIBS - this contains both the Qt and the kdecore library
# KDE3_DCOPIDL_EXECUTABLE - the dcopidl executable
# KDE3_DCOPIDL2CPP_EXECUTABLE - the dcopidl2cpp executable
# KDE3_KCFGC_EXECUTABLE - the kconfig_compiler executable
@@ -56,8 +56,8 @@ include(FindQt3)
# It creates and installs an appropriate libtool la-file.
#
# KDE3_ADD_KDEINIT_EXECUTABLE(name file1 ... fileN )
# Create a KDE application in the form of a module loadable via kdeinit.
# A library named kdeinit_<name> will be created and a small executable which links to it.
#
# The option KDE3_ENABLE_FINAL to enable all-in-one compilation is
# no longer supported.
@@ -122,7 +122,7 @@ ENDIF(KDECONFIG_EXECUTABLE)
# at first the KDE include direcory
# kpassdlg.h comes from kdeui and doesn't exist in KDE4 anymore
FIND_PATH(KDE3_INCLUDE_DIR kpassdlg.h
HINTS
$ENV{KDEDIR}/include
@@ -139,7 +139,7 @@ FIND_PATH(KDE3_INCLUDE_DIR kpassdlg.h
# SET(KDE3_INCLUDE_DIR "/usr/include/kde")
#now the KDE library directory
-FIND_LIBRARY(KDE3_KDECORE_LIBRARY NAMES kdecore
+FIND_LIBRARY(KDE3_KDECORE_LIBRARY NAMES tdecore
HINTS
$ENV{KDEDIR}/lib
${KDE3PREFIX}/lib
@@ -330,7 +330,7 @@ IF (LIB_SUFFIX)
${LIB_SEARCH_PATHES})
ENDIF (LIB_SUFFIX)
-FIND_LIBRARY(KDE3_UI_LIBRARY NAMES kdeui
+FIND_LIBRARY(KDE3_UI_LIBRARY NAMES tdeui
PATHS
${LIB_SEARCH_PATHES}
)
@@ -355,7 +355,7 @@ FIND_LIBRARY(KDE3_WALLET_LIBRARY NAMES kwalletclient
${LIB_SEARCH_PATHES}
)
-FIND_LIBRARY(KDE3_KINIT_KDED_LIBRARY NAMES kdeinit_kded
+FIND_LIBRARY(KDE3_KINIT_KDED_LIBRARY NAMES tdeinit_kded
PATHS
${LIB_SEARCH_PATHES}
)
@@ -7,7 +7,7 @@ include(FindQt3)
# KDE3_INCLUDE_DIRS - the KDE and the Qt include directory, for use with INCLUDE_DIRECTORIES()
# KDE3_LIB_DIR - the directory where the KDE libraries are installed, for use with LINK_DIRECTORIES()
-# QT_AND_KDECORE_LIBS - this contains both the Qt and the kdecore library
+# QT_AND_KDECORE_LIBS - this contains both the Qt and the tdecore library
# KDE3_DCOPIDL_EXECUTABLE - the dcopidl executable
# KDE3_DCOPIDL2CPP_EXECUTABLE - the dcopidl2cpp executable
@@ -56,8 +56,8 @@ include(FindQt3)
#
# KDE3_ADD_KDEINIT_EXECUTABLE(name file1 ... fileN )
-# Create a KDE application in the form of a module loadable via kdeinit.
-# A library named kdeinit_<name> will be created and a small executable which links to it.
+# Create a KDE application in the form of a module loadable via tdeinit.
+# A library named tdeinit_<name> will be created and a small executable which links to it.
#
# The option KDE3_ENABLE_FINAL to enable all-in-one compilation is
@@ -122,7 +122,7 @@ ENDIF(KDECONFIG_EXECUTABLE)
# at first the KDE include direcory
-# kpassdlg.h comes from kdeui and doesn't exist in KDE4 anymore
+# kpassdlg.h comes from tdeui and doesn't exist in KDE4 anymore
FIND_PATH(KDE3_INCLUDE_DIR kpassdlg.h
HINTS